run_server

Function run_server 

pub fn run_server(preview_features: PreviewFeatures) -> Result<()>
Synchronous entry point used by the binary subcommand (creates a tokio runtime and starts the stdio server).